@@ -10,9 +10,9 @@ from schemey.schema_context import SchemaContext
 
 class ArraySchemaFactory(SchemaFactoryABC):
 
-    def create(self, type_: Type, context: SchemaContext) -> Optional[SchemaABC]:
+    def create(self, type_: Type, default_value, context: SchemaContext) -> Optional[SchemaABC]:
         origin = typing_inspect.get_origin(type_)
         if origin is list:
             args = typing_inspect.get_args(type_)
             schema = context.get_schema(args[0])
-            return ArraySchema[T](schema)
+            return ArraySchema[T](schema, default_value=default_value)
